mlbench_core.dataset
--------------------

.. automodule:: mlbench_core.dataset
.. currentmodule:: mlbench_core.dataset


linearmodels
~~~~~~~~~~~~
.. automodule:: mlbench_core.dataset.linearmodels
.. currentmodule:: mlbench_core.dataset.linearmodels

pytorch
+++++++

.. automodule:: mlbench_core.dataset.linearmodels.pytorch
.. currentmodule:: mlbench_core.dataset.linearmodels.pytorch

load_libsvm_lmdb
''''''''''''''''

.. autofunction:: load_libsvm_lmdb

Partition
'''''''''

.. autoclass:: Partition
    :members:

DataPartitioner
'''''''''''''''

.. autoclass:: DataPartitioner
    :members:



imagerecognition
~~~~~~~~~~~~~~~~

.. automodule:: mlbench_core.dataset.imagerecognition
.. currentmodule:: mlbench_core.dataset.imagerecognition

pytorch
+++++++

.. automodule:: mlbench_core.dataset.imagerecognition.pytorch
.. currentmodule:: mlbench_core.dataset.imagerecognition.pytorch

CIFAR10V1
'''''''''

.. autoclass:: CIFAR10V1
    :members:

Imagenet
''''''''

.. autoclass:: Imagenet
    :members:

Partition
'''''''''

.. autoclass:: Partition
    :members:

DataPartitioner
'''''''''''''''

.. autoclass:: DataPartitioner
    :members:

tensorflow
++++++++++

.. automodule:: mlbench_core.dataset.imagerecognition.tensorflow
.. currentmodule:: mlbench_core.dataset.imagerecognition.tensorflow

DatasetCifar
''''''''''''

.. autoclass:: DatasetCifar
    :members:
